@@ -6,14 +6,22 @@ pub use miette_derive::*;
 
 pub use error::*;
 pub use eyreish::*;
+#[cfg(feature = "fancy")]
+pub use handler::*;
 pub use handlers::*;
 pub use named_source::*;
+#[cfg(feature = "fancy")]
+pub use panic::*;
 pub use protocol::*;
 
 mod chain;
 mod error;
 mod eyreish;
+#[cfg(feature = "fancy")]
+mod handler;
 mod handlers;
 mod named_source;
+#[cfg(feature = "fancy")]
+mod panic;
 mod protocol;
 mod source_impls;
